as_brand_yml: Create a Brand instance from a list or character vector.

View source: R/read_brand_yml.R

as_brand_ymlR Documentation

Create a Brand instance from a list or character vector.

Description

Create a Brand instance from a list or character vector.

Usage

as_brand_yml(brand)

Arguments

brand

A list or string of YAML representing the brand, or a path to a brand.yml file.

Value

A normalized brand_yml list.

Examples

as_brand_yml("
meta:
  name: Example Brand

color:
  primary: '#FF5733'
  secondary: '#33FF57'
")

as_brand_yml(list(
  meta = list(name = "Example Brand"),
  color = list(primary = "#FF5733", secondary = "#33FF57")
))


brand.yml documentation built on Nov. 6, 2025, 5:06 p.m.