brand.yml-package: brand.yml: Unified Branding with a Simple YAML File

brand.yml-packageR Documentation

brand.yml: Unified Branding with a Simple YAML File

Description

Read and process 'brand.yml' 'YAML' files. 'brand.yml' is a simple, portable 'YAML' file that codifies your company's brand guidelines into a format that can be used by 'Quarto', 'Shiny' and 'R' tooling to create branded outputs. Maintain unified, branded theming for web applications to printed reports to dashboards and presentations with a consistent look and feel.

Author(s)

Maintainer: Garrick Aden-Buie garrick@posit.co (ORCID)

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also

Useful links:


brand.yml documentation built on Nov. 6, 2025, 5:06 p.m.