| brand_sass_color | R Documentation |
Creates Sass variables for brand colors with the brand_color_ prefix.
Excludes the color palette which is handled by brand_sass_color_palette().
brand_sass_color(brand)
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
A list with one component:
defaults: Sass variable definitions with !default flag
Other brand.yml Sass helpers:
brand_sass_color_palette(),
brand_sass_defaults_bootstrap(),
brand_sass_fonts(),
brand_sass_typography()
brand <- list(
color = list(
primary = "#007bff",
danger = "#dc3545"
)
)
brand_sass_color(brand)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.