| brand_sass_defaults_bootstrap | R Documentation |
Creates Sass variables and a sass layer from Bootstrap defaults defined in the brand object. Allows overriding defaults from other sources like Shiny themes.
brand_sass_defaults_bootstrap(brand, overrides = "shiny.theme")
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
overrides |
Path to override defaults, e.g., "shiny.theme" |
A list with two components:
defaults: Sass variable definitions with !default flag
layer: A sass_layer object with functions, mixins, and rules
Other brand.yml Sass helpers:
brand_sass_color(),
brand_sass_color_palette(),
brand_sass_fonts(),
brand_sass_typography()
brand <- list(
defaults = list(
bootstrap = list(
defaults = list(
primary = "#007bff",
enable_rounded = TRUE
),
functions = "@function brand-function() { @return true; }"
),
shiny = list(
theme = list(
defaults = list(
primary = "#428bca" # Override bootstrap primary
)
)
)
)
)
brand_sass_defaults_bootstrap(brand)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.