| brand_sass_typography | R Documentation |
Creates Sass variables for typography settings with the brand_typography_ prefix.
Font size values in pixels are converted to rem units, and color references are resolved.
brand_sass_typography(brand)
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
A list with one component:
defaults: Sass variable definitions with !default flag
Other brand.yml Sass helpers:
brand_sass_color(),
brand_sass_color_palette(),
brand_sass_defaults_bootstrap(),
brand_sass_fonts()
brand <- list(
typography = list(
base = list(
size = "16px",
"line-height" = 1.5
),
headings = list(
weight = "bold",
style = "normal"
)
)
)
brand_sass_typography(brand)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.