| theme_brand_thematic | R Documentation |
Apply thematic styling using explicit colors or by automatically extracting colors from a brand.yml file. This function sets global theming for base R graphics.
theme_brand_thematic(
brand = NULL,
background = NULL,
foreground = NULL,
accent = NULL,
...
)
theme_brand_thematic_on(
brand = NULL,
background = NULL,
foreground = NULL,
accent = NULL,
...
)
brand |
One of:
|
background |
The background color, defaults to |
foreground |
The foreground color, defaults to |
accent |
The accent color, defaults to |
... |
Additional arguments passed to |
thematic_theme() returns a theme object as a list (which can be
activated with thematic_with_theme() or thematic_set_theme()).
thematic_on(), thematic_off(), and thematic_shiny() all return
the previous global theme.
theme_brand_thematic(): brand.yml wrapper for
thematic::thematic_theme()
theme_brand_thematic_on(): brand.yml wrapper for
thematic::thematic_theme()
See the "Branded Theming" section of theme_brand_ggplot2() for
more details on how the brand argument works.
Other branded theming functions:
theme_brand_flextable(),
theme_brand_ggplot2(),
theme_brand_gt(),
theme_brand_plotly()
brand <- as_brand_yml('
color:
palette:
black: "#1A1A1A"
white: "#F9F9F9"
orange: "#FF6F20"
foreground: black
background: white
primary: orange')
library(ggplot2)
thematic::thematic_with_theme(theme_brand_thematic(brand), {
ggplot(diamonds, aes(carat, price)) +
geom_point()
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.