View source: R/read_brand_yml.R
| as_brand_yml | R Documentation |
Create a Brand instance from a list or character vector.
as_brand_yml(brand)
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
A normalized brand_yml list.
as_brand_yml("
meta:
name: Example Brand
color:
primary: '#FF5733'
secondary: '#33FF57'
")
as_brand_yml(list(
meta = list(name = "Example Brand"),
color = list(primary = "#FF5733", secondary = "#33FF57")
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.