Learn R Programming

brand.yml (version 0.1.0)

as_brand_yml: Create a Brand instance from a list or character vector.

Description

Create a Brand instance from a list or character vector.

Usage

as_brand_yml(brand)

Value

A normalized brand_yml list.

Arguments

brand

A list or string of YAML representing the brand, or a path to a brand.yml file.

Examples

Run this code
as_brand_yml("
meta:
  name: Example Brand

color:
  primary: '#FF5733'
  secondary: '#33FF57'
")

as_brand_yml(list(
  meta = list(name = "Example Brand"),
  color = list(primary = "#FF5733", secondary = "#33FF57")
))

Run the code above in your browser using DataLab