| brand_sass_color_palette | R Documentation |
Converts color palette entries from a brand object to Sass variables with
brand- prefix and CSS custom properties with --brand- prefix.
brand_sass_color_palette(brand)
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
A list with two components:
defaults: Sass variable definitions with !default flag
rules: CSS rules that define custom properties in :root
Other brand.yml Sass helpers:
brand_sass_color(),
brand_sass_defaults_bootstrap(),
brand_sass_fonts(),
brand_sass_typography()
brand <- list(
color = list(
palette = list(
primary = "#007bff",
secondary = "#6c757d"
)
)
)
brand_sass_color_palette(brand)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.