| brand_sass_fonts | R Documentation |
Creates Sass variables and CSS rules for fonts defined in the brand object. Supports Google fonts, Bunny fonts, and file-based fonts.
brand_sass_fonts(brand)
brand |
A list or string of YAML representing the brand, or a path to a brand.yml file. |
A list with two components:
defaults: Sass variables for font definitions
rules: CSS rules for applying fonts via classes
Other brand.yml Sass helpers:
brand_sass_color(),
brand_sass_color_palette(),
brand_sass_defaults_bootstrap(),
brand_sass_typography()
brand <- list(
typography = list(
fonts = list(
list(
family = "Roboto",
source = "google",
weight = c(400, 700),
style = "normal"
)
)
)
)
brand_sass_fonts(brand)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.